Fintualistic
===============
This project is intended to solve a basic problem for fintualees: plotting. With this library a python programmer will be able to plot their charts with a fintualistic style, perfect for fintualist articles, presentations and Twitter threads.

Installing
============

    pip install fintualistic

Usage
=====

.. code-block:: bash

    >>> from fintualistic import *

Plotting functions implemented

- **plot_series**

- **plot_bar**

- **plot_combo_series**

- **plot_pie**

- **plot_scatter**

- **plot_dist**

- **plot_area**